# Examples

Here are some examples of how to use the 'Blueprints'.

- [Nominal Concrete Cover](nominal_concrete_cover.ipynb)
- [Create a Rectangular Reinforced Cross-section](rectangular_reinforced_concrete_cross_section.md)
- [Create a Custom Reinforced Cross-section](rectangular_custom_reinforced_concrete_cross_section.md)